"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const unified_lint_rule_1 = __importDefault(require("unified-lint-rule"));
const gray_matter_1 = __importDefault(require("gray-matter"));
const ajv_1 = __importDefault(require("ajv"));
// JSON schema for front-matter validation
const playgroundExampleSchema = {
    type: 'object',
    properties: {
        examples: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    label: { type: 'string' },
                    description: { type: 'string' },
                },
                required: ['name', 'label', 'description'],
                additionalProperties: false,
            },
        },
    },
    required: ['examples'],
};
function validateFrontMatterInMarkdown(tree, file) {
    function check(node) {
        const content = file.toString();
        const ajv = new ajv_1.default();
        const validateSchema = ajv.compile(playgroundExampleSchema);
        const exampleData = (0, gray_matter_1.default)(content);
        const isValid = validateSchema(exampleData);
        if (!isValid) {
            file.message(`Example front matter for playground is invalid.`, node);
        }
    }
    (0, unist_util_visit_1.default)(tree, ['containerDirective'], check);
}
module.exports = (0, unified_lint_rule_1.default)('sfdocs-lint:remark-lint-markdown-frontmatter-playground', validateFrontMatterInMarkdown);
//# sourceMappingURL=index.js.map