import visit from 'unist-util-visit';
import { VFile } from 'vfile';
import rule from 'unified-lint-rule';
import grayMatter from 'gray-matter';
import Ajv from 'ajv';

// JSON schema for front-matter validation
const playgroundExampleSchema = {
    type: 'object',
    properties: {
        examples: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    label: { type: 'string'},
                    description: { type: 'string'},
                },
                required: ['name', 'label', 'description'],
                additionalProperties: false,
            },
        },
    },
    required: ['examples'],
};

function validateFrontMatterInMarkdown(tree: any, file: VFile): void {
    function check(node): void {
        const content = file.toString();
        const ajv = new Ajv();
        const validateSchema = ajv.compile(playgroundExampleSchema);
        const exampleData = grayMatter(content);

        const isValid = validateSchema(exampleData);
        
        if(!isValid) {
            file.message(`Example front matter for playground is invalid.`, node);
        }
    }

    visit(tree, ['containerDirective'], check);
}

export = rule('sfdocs-lint:remark-lint-markdown-frontmatter-playground', validateFrontMatterInMarkdown);